@@ -6,7 +6,7 @@ def main():
     parser.add_argument("command", nargs="+")
 
     # Handle -c, -p, --release arguments:
-    qibuild.parsers.build_parser(parser)
+    qisys.parsers.build_config(parser)
     build_worktree = qibuild.parsers.get_build_worktree(args)
     build_config = qibuild.parser.get_build_config(args)
     build_worktree.build_config = build_config
@@ -17,9 +17,5 @@ def main():
 
     run_from_venv(args.command)
 
-
-
-
-
 if __name__ == "__main__":
     main()
