@@ -1,4 +1,5 @@
 import os
+import copy
 import operator
 
 from qisys import ui
@@ -252,7 +253,9 @@ class GitWorkTree(qisys.worktree.WorkTreeObserver):
             if project.default_branch is None:
                 continue
             branch_name = project.default_branch.name
-            ok, err = self._safe_checkout(project, branch_name, force=force)
+            remote_name = project.default_remote.name
+            git = qisrc.git.Git(project.path)
+            ok, err = git.safe_checkout(branch_name, remote_name, force=force)
             if not ok:
                 errors.append((project.src, err))
         if not errors:
@@ -261,23 +264,26 @@ class GitWorkTree(qisys.worktree.WorkTreeObserver):
         for (project, error) in errors:
             ui.info(project, ":", error)
 
-    def _safe_checkout(self, project, branch, force=False):
-        """ Helper for self.checkout """
-        git = qisrc.git.Git(project.path)
-        current_branch = git.get_current_branch()
-        if not current_branch:
-            return False, "not on any branch, skipping"
-        clean, error = git.require_clean_worktree()
-        if not clean and not force:
-            return False, error
-        checkout_args = [branch]
-        if force:
-            checkout_args.append("--force")
-        rc, out = git.checkout(*checkout_args, raises=False)
-        if rc != 0:
-            return False, "Checkout failed " + out
-        return True, None
+    def get_projects_on_branch(self, branch):
+        """ Return a dict (src, project) for every project as configured
+        on the given branch of the manifest.
 
+        """
+        res = dict()
+        ref = "origin/" + branch
+        manifest = qisrc.manifest.from_git_repo(self._syncer.manifest_repo, ref)
+        if not manifest:
+            raise Exception("Could not read manifest on %s"% ref)
+        groups = self._syncer.manifest.groups
+        repos = manifest.get_repos(groups=groups)
+        for repo in repos:
+            project = self.find_repo(repo)
+            if project:
+                # Make a copy so that we do not modify the projects in place
+                project_copy = copy.deepcopy(project)
+                project_copy.read_remote_config(repo, quiet=True)
+                res[project_copy.src] = project_copy
+        return res
 
     def remove_repo(self, project):
         """ Remove a project from the worktree """
